.. include:: ../README.rst

User documentation
==================

.. toctree::
    :maxdepth: 3

    installation/index
    changes
    authors

Reference documentation
=======================

.. toctree::
    :maxdepth: 3

    api/index

Development documentation
=========================

.. toctree::
    :maxdepth: 3

    development/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

